
*==
*=====
*=========
*============= Basic cleaning
* Import data
import excel "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data/Raw data/Raw data - 1 sheet.xlsx", sheet("2010") firstrow clear

* Drop irrelevant variables created by Excel (because of how the data came)
drop  X AH AR BB BL BV CF

* Fixing inconsistencies in unique ID. First by generating an ID for the "0000" (private schools mostly)
bysort name code circuit province canton district town: generate id = 100000000*runiform()
tostring id, replace force
replace code=code+id if code=="0000"

* Checking duplicate codes by year, and assigning new codes in those cases
bysort code year: gen count=_N

replace code="9999" if name=="LOMA LINDA"
replace code="99999" if name=="SANTO DOMINGO" & code=="1903" & year==2018
replace code="999999" if name=="CASAMATA" & code=="1750" & year==2014
replace code="0000" if code==""
replace code=code+id if code=="0000"

* Homogenizing province names
replace province="SAN JOSE" if province=="SAN JOSÉ"
replace province="LIMON" if province=="LIMÓN"

* Checking that this worked
drop count
bysort code year: gen count=_N
count if count>1

*==
*=====
*=========
*============= Creating important variables

* Create two additional variables for easier tabulations
gen rural=(zone=="RURAL")
gen public=(type=="PÚBLICO")

* Create a student/teacher ratio
gen stud_teacher_ratio= enr_init_total/teacher_total

* Create a female/male students ratio
gen share_female_stud=enr_init_female/(enr_init_female+enr_init_male)
gen share_female_stud_f=enr_final_female/(enr_final_female+enr_final_male)
replace share_female_stud=share_female_stud_f if share_female_stud==.
drop share_female_stud_f

* Create a female/male teacher ratio
gen share_female_teacher=teacher_female/(teacher_female+teacher_male)

* Cleaning up "repitent" vars
replace repitent_total="" if repitent_total=="…"  
replace repitent_male="" if repitent_male=="…"  
replace repitent_female="" if repitent_female=="…"  
forvalues i = 1(1)6{
replace repitent_`i'="" if repitent_`i'=="…"  
}
destring repitent_*, replace

* Destringing important variables
forvalues i = 1(1)6{
destring aplazad_`i', replace
destring fail_`i', replace
destring repitent_`i', replace
destring repitent_*, replace
destring dropout_`i', replace
destring enr_final_`i', replace
destring enr_init_`i', replace
}


* Create variables that calculate share of aplazados and failing students (first, destringing)
forvalues i = 1(1)6{
replace aplazad_`i'=0 if aplazad_`i'==. & enr_final_`i'!=.
replace fail_`i'=0 if fail_`i'==. & enr_final_`i'!=.
replace dropout_`i'=0 if dropout_`i'==. & dropout_`i'!=.


gen share_aplaz_fail_`i'=(aplazad_`i'+fail_`i')/(enr_final_`i')
replace share_aplaz_fail_`i'=0 if enr_final_`i'==. | enr_final_`i'==0

gen share_aplaz_`i'=(aplazad_`i')/enr_final_`i'
replace share_aplaz_`i'=0 if enr_final_`i'==. | enr_final_`i'==0

gen share_fail_`i'=(fail_`i')/enr_final_`i'
replace share_fail_`i'=0 if enr_final_`i'==. | enr_final_`i'==0

gen share_dropout_`i'=(dropout_`i')/enr_init_`i'
replace share_dropout_`i'=0 if enr_final_`i'==. | enr_final_`i'==0
}


* Create failing rates at school-level
bysort code year: gen total_share_fail=(fail_1+fail_2+fail_3+fail_4+fail_5+fail_6)/enr_final_total
bysort code year: gen total_share_aplaz=(aplazad_1+aplazad_2+aplazad_3+aplazad_4+aplazad_5+aplazad_6)/enr_final_total
bysort code year: gen total_share_aplaz_fail=((aplazad_1+aplazad_2+aplazad_3+aplazad_4+aplazad_5+aplazad_6)+(fail_1+fail_2+fail_3+fail_4+fail_5+fail_6))/enr_final_total


* Encoding variables
encode province, gen(province_enc)
encode circuit, gen(circuit_enc)

*=== Merging pre-k data
merge m:m province canton district zone using "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data/Clean data/prek_data.dta"

drop if _merge==2
drop _merge

replace pk_mean_schools=0 if pk_mean_schools==.
replace pk_enrollment=0 if pk_enrollment==.

bysort province canton district zone: egen total_1_graders=total(enr_init_1)
gen pk_students_to_1_graders=pk_enrollment/total_1_graders
* Note that this share is PK in 2018/1st graders in 2018

* Drop further variables
drop name region circuit province_code canton_code province canton district town type zone enr_init_male enr_init_female repitent_total dropout_total enr_init_1 enr_init_2 enr_init_3 enr_init_4 enr_init_5 enr_init_6 repitent_male repitent_female repitent_1 repitent_2 repitent_3 repitent_4 repitent_5 repitent_6 dropout_male dropout_female dropout_1 dropout_2 dropout_3 dropout_4 dropout_5 dropout_6 passed_total passed_male passed_female passed_1 passed_2 passed_3 passed_4 passed_5 passed_6 aplazad_total aplazad_male aplazad_female aplazad_1 aplazad_2 aplazad_3 aplazad_4 aplazad_5 aplazad_6 fail_total fail_male fail_female fail_1 fail_2 fail_3 fail_4 fail_5 fail_6 teacher_male teacher_female id count total_1_graders

* Order data
order year code province_enc circuit_enc rural public enr_init_total teacher_total  stud_teacher_ratio share_female_stud share_female_teacher share_fail_* share_aplaz_* share_aplaz_fail_* share_drop* total_share_* pk_mean_schools pk_enrollment pk_students_to_1_graders
												 
* Reshape data                                             
reshape long share_aplaz_ share_fail_ share_aplaz_fail_ share_dropout_ enr_final_, i(year code) j(grade)

* Save data
save "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data\Clean data\Clean_raw_data", replace

*==
*=====
*=========
*============= Preparing for analysis
use "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data\Clean data\Clean_raw_data", clear

* Standardizing outcomes here
bysort  grade: egen mean_fail=mean(share_fail_)
bysort  grade: egen sd_fail=sd(share_fail_)
bysort  grade: egen mean_aplaz=mean(share_aplaz_)
bysort  grade: egen sd_aplaz=sd(share_aplaz_)
bysort  grade: egen mean_aplaz_fail=mean(share_aplaz_fail_)
bysort  grade: egen sd_aplaz_fail=sd(share_aplaz_fail_)
bysort  grade: egen mean_dropout=mean(share_dropout_)
bysort  grade: egen sd_dropout=sd(share_dropout_)

* Creating other y variables
gen std_fail=(share_fail_-mean_fail)/sd_fail
gen std_aplaz=(share_aplaz_-mean_aplaz)/sd_aplaz_fail
gen std_aplaz_fail=(share_aplaz_fail_-mean_aplaz_fail)/sd_aplaz_fail
gen std_dropout=(share_dropout_-mean_dropout)/sd_dropout

* Creating alternative y variables (count of total final enrollment by grade)

gen y_var_aplaz_fail=share_aplaz_fail_*enr_final_
gen y_var_fail=share_fail_*enr_final_
gen y_var_aplaz=share_aplaz_*enr_final_
gen y_var_dropout=share_dropout_*enr_final_

drop mean_* sd_*

* Merging health and infrastructure variables
merge m:m code using "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data/Clean data/Clean_infra_health.dta"
count
* Create a unique code-grade ID
tostring grade, replace
replace code=code+grade
destring code, replace

* Destring grade to make it easier to incorporate into regs
destring grade, replace

* Renaming some vars before ordering
rename share_aplaz_fail_ share_aplaz_fail
rename share_aplaz_ share_aplaz
rename share_fail_ share_fail
rename share_dropout_ share_dropout

* Ordering variables
order year code grade province_enc circuit_enc district_code rural public enr_init_total teacher_total stud_teacher_ratio share_female_stud share_female_teacher pk_mean_schools pk_enrollment pk_students_to_1_graders infra_index_per_capita infra_index health_index join_infra_index percent_underweight percent_overweight_obes percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence y_var_aplaz_fail y_var_fail y_var_aplaz y_var_dropout share_fail share_aplaz_fail share_fail share_aplaz share_dropout std_fail std_aplaz std_aplaz_fail std_dropout enr_final_total enr_final_male enr_final_female enr_final_  total_share_fail total_share_aplaz total_share_aplaz_fail

* Dropping all variables that we no longer need
drop _merge percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence

save "/Users/danielrodriguezsegura/Box Sync/Personal research/CR, Tanzania and India - Grade Repetition/Costa Rica/Data/Clean data/Ready for regs/Full clean data.dta", replace
