/*
*================= CLEAN UP COVARIATES: GRADE REPETITION POLICY ANALYSIS *=================

[ PROJ ] First grade repetition in 1st grade in CR
[ AUTH ] Dan Rodriguez
[ INIT ] 7 July 2019
[ UPDT ] 9 July 2019
*/

*=================
***** CLEANING UP INFRA AND HEALTH COVARIATES
cls
clear all
set more off, perm
global user=c(username)

global project_folder ""
global health "${project_folder}/harmonized_health"
global infra "${project_folder}/harmonized_infra"

*===============================================================================
*===============================================================================
* This section cleans up infra-related data by school and creates relevant variables
			
use "$infra", clear

* Checking that different schools don't have the same code
bysort code year: gen check=_N
tab name if check>1

* Notice that there are two different schools with the same code, which should 
* not happen, but that is how the data came. I will assign a new code here for one
* and also do it on the health data
* Fixing inconsistencies in unique ID. First by generating an ID for the "0000" (private schools mostly)
set seed 1000
bysort name code circuit province canton district: generate id = 100000000*runiform()
tostring id, replace force
replace code=code+id if code=="0000"

* Checking duplicate codes by year, and assigning new codes in those cases
bysort code year: gen count=_N
replace code="2369" if name=="CERRILLOS" & circuit=="NICOYA"
replace code="9999" if name=="LOMA LINDA"
replace code="99999" if name=="SANTO DOMINGO" & code=="1903" & year==2018
replace code="999999" if name=="CASAMATA" & code=="1750" & year==2014
replace code="0000" if code==""
replace code=code+id if code=="0000"

* Homogenizing province names
replace province="SAN JOSE" if province=="SAN JOSÉ"
replace province="LIMON" if province=="LIMÓN"

* Saving for now
save "${project_folder}/1-Processed data/infra", replace

*===============================================================================
*===============================================================================
* Import data
use "$health", clear

* Destring geographic variables
foreach v in circuit_code province_code canton_code district_code{
destring `v', replace
}

* Correcting names of oral_condition vars (instead of the root being "oral_condition_",
* it should be "oral_condition":
forvalues i=1(1)6{
rename oral_condition__`i' oral_condition_`i' 
}
rename oral_condition__total oral_condition_total 

* Create an urban and a rural indicator
gen rural=0
gen urban=0
replace rural=1 if zone=="RURAL"
replace urban=1 if zone=="URBANA"

* Changing code number for two different school that the data incorrectly reports
* the same code
* Fixing inconsistencies in unique ID. First by generating an ID for the "0000" (private schools mostly)
set seed 1000
bysort name code circuit province canton district: generate id = 100000000*runiform()
tostring id, replace force
replace code=code+id if code=="0000"

* Checking duplicate codes by year, and assigning new codes in those cases
bysort code year: gen count=_N
replace code="2369" if name=="CERRILLOS" & circuit=="NICOYA"
replace code="9999" if name=="LOMA LINDA"
replace code="99999" if name=="SANTO DOMINGO" & code=="1903" & year==2018
replace code="999999" if name=="CASAMATA" & code=="1750" & year==2014
replace code="0000" if code==""
replace code=code+id if code=="0000"

* Homogenizing province names
replace province="SAN JOSE" if province=="SAN JOSÉ"
replace province="LIMON" if province=="LIMÓN"

* Gen overweight_obes variable
forvalues i=1(1)6{
gen overweight_obes_`i'=overweight_`i'+obesity_`i'
}
gen overweight_obes_total=overweight_obes_1+overweight_obes_2+overweight_obes_3+overweight_obes_4+overweight_obes_5+overweight_obes_6

* Create relative values 
foreach v in underweight overweight_obes visual_problems hearing_problems ///
oral_condition incomplete_vaccin anemia additions family_violence {
	gen percent_`v'=`v'_total/enrollment_total
}

* Ordering variables
order year name code circuit circuit_code province_code canton_code district_code ///
province canton district zone urban rural enrollment_total percent_underweight ///
percent_overweight_obes percent_visual_problems percent_hearing_problems ///
percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions ///
percent_family_violence 

* Merging the data. notice that only 0.35% of the observations are not merged:
merge m:m code year using "${project_folder}/1-Processed data/infra", force
drop if _merge==2

* Notice that there are two school-years combination that have repeated data. Code 3676 
* doesn't have a name in one of the observations, so I will drop this observation. For
* the other case, I will just randomly keep one. 
bysort code year: gen count1= _n
drop if count1>1
drop count1

*===============================================================================
*===============================================================================
* Final clean up of the data to merge

* Create controls per capita (school enrollment)
global controls_preliminary "classrooms1_6 it_lab library gym shop other_shops food_kiosk toilets sinks tv video_beam dvd desktop_internet laptop_internet"
foreach v of global controls_preliminary{
gen `v'_per_capita=`v'/enrollment_total
}

global controls_per_capita "classrooms1_6_per_capita it_lab_per_capita library_per_capita gym_per_capita shop_per_capita other_shops_per_capita food_kiosk_per_capita toilets_per_capita sinks_per_capita tv_per_capita video_beam_per_capita dvd_per_capita desktop_internet_per_capita laptop_internet_per_capita"
global controls_absolute "electricity_reliable water_reliable sanit_bathroom health emergency first_aid internet" 
global controls $controls_per_capita $controls_absolute

*=== Create other controls:
* Reliable electricity
gen electricity_reliable=0
replace electricity_reliable=1 if electricity_main_1==1 | electricity_main_2==1 | electricity_main_3==1

* Reliable water source
gen water_reliable=0
replace water_reliable=1 if water_main_1==1 | water_main_2==1 | water_main_3==1 | water_main_4==1

* Sanitary plumbing in bathrooms
gen sanit_bathroom=0
replace sanit_bathroom=1 if bathrooms_main_1==1 | bathrooms_main_2==1

* Is there a health service within the school?
gen health=0
replace health=1 if health_serv_yes==1

* Is there an emergency plan in place?
gen emergency=0
replace emergency=1 if emerg_plans_yes==1

* Is there a first aid kit and someone trained to use it?
gen first_aid=0
replace first_aid=1 if first_aid_yes==1

*Is there internet?
gen internet=0
replace internet=1 if internet_yes==1

keep year code $controls enrollment_total percent_underweight percent_overweight_obes percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence

drop if year==2012 | year==2013

* Creating an infrastructure index
foreach v of varlist percent_underweight percent_overweight_obes percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence classrooms1_6_per_capita it_lab_per_capita library_per_capita gym_per_capita shop_per_capita other_shops_per_capita food_kiosk_per_capita toilets_per_capita sinks_per_capita tv_per_capita video_beam_per_capita dvd_per_capita desktop_internet_per_capita laptop_internet_per_capita electricity_reliable water_reliable sanit_bathroom health emergency first_aid internet{
replace `v'=0.001 if `v'==.
replace `v'=0.001 if `v'==0
}

gen infra_index_per_capita=(classrooms1_6_per_capita*it_lab_per_capita*library_per_capita*gym_per_capita*food_kiosk_per_capita*toilets_per_capita*sinks_per_capita*desktop_internet_per_capita*laptop_internet_per_capita)^(1/9)

egen mean_index_per_cap=mean(infra_index_per_capita)
egen sd_index_per_cap=sd(infra_index_per_capita)
replace infra_index_per_capita=(infra_index_per_capita-mean_index_per_cap)/sd_index_per_cap

gen infra_index=(electricity_reliable*water_reliable*sanit_bathroom*health*emergency*first_aid* internet)^(1/7)

egen mean_index=mean(infra_index)
egen sd_index=sd(infra_index)
replace infra_index=(infra_index-mean_index)/sd_index

gen join_infra_index=(infra_index_per_capita)*(9/16)+(infra_index)*(7/16)


* Creating a health index
gen health_index=(-1)*(percent_underweight*percent_overweight_obes*percent_visual_problems*percent_hearing_problems*percent_oral_condition*percent_incomplete_vaccin*percent_anemia*percent_additions*percent_family_violence)^(1/9)

egen mean_health_index=mean(health_index)
egen sd_health_index=sd(health_index)

replace health_index=(mean_health_index-health_index)/sd_health_index

* Creating a unique data set with information for all schools
keep code infra_index_per_capita infra_index health_index join_infra_index percent_underweight percent_overweight_obes percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence

collapse (mean) infra_index_per_capita infra_index health_index join_infra_index percent_underweight percent_overweight_obes percent_visual_problems percent_hearing_problems percent_oral_condition percent_incomplete_vaccin percent_anemia percent_additions percent_family_violence, by(code)


*=== Save the ouput
save "$built_data/Clean_infra_health", replace
